@@ -16,5 +16,5 @@ sys.path.append(eventPublisherDirectory)
 
 import EventHub.SendEvents as SendEvents
 
-SendEvents.send_events_a('[{"name":"a"}, {"name":"aa"}]')
+SendEvents.run_send_events('order.create', 'Development', 'fla-105-code', 'fla-105', '[{"entityId":"a"}]')
 #Environment.set_environment()
